from nevada.Common.Connector import *
from typing import List
import json

class RelKwdStatObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            s = json.loads(json_def)
        else:
            s = json_def
        self.relKeyword = None if 'relKeyword' not in s else s['relKeyword']
        self.monthlyPcQcCnt = None if 'monthlyPcQcCnt' not in s else s['monthlyPcQcCnt']
        self.monthlyMobileQcCnt = None if 'monthlyMobileQcCnt' not in s else s['monthlyMobileQcCnt']
        self.monthlyAvePcClkCnt = None if 'monthlyAvePcClkCnt' not in s else s['monthlyAvePcClkCnt']
        self.monthlyAveMobileClkCnt = None if 'monthlyAveMobileClkCnt' not in s else s['monthlyAveMobileClkCnt']
        self.monthlyAvePcCtr = None if 'monthlyAvePcCtr' not in s else s['monthlyAvePcCtr']
        self.monthlyAveMobileCtr = None if 'monthlyAveMobileCtr' not in s else s['monthlyAveMobileCtr']
        self.plAvgDepth = None if 'plAvgDepth' not in s else s['plAvgDepth']
        self.compIdx = None if 'compIdx' not in s else s['compIdx']

class RelKwdStat:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    RelKwdStatObjectList = List[RelKwdStatObject]

    def get_json(self, siteId: str = None, biztpId: int = None, hintKeywords: str = None, event: int = None,
                              month: int = None, showDetail: str = '1'):
        query = {'siteId': siteId,
                 'biztpId': biztpId,
                 'hintKeywords': hintKeywords,
                 'event': event,
                 'month': month,
                 'showDetail': showDetail
                 }
        result = self.conn.get(uri='/keywordstool', query=query)
        result = result['keywordList']
        return result

    def get_list(self, siteId: str = None, biztpId: int = None, hintKeywords: str = None, event: int = None,
                              month: int = None, showDetail: str = '1') -> RelKwdStatObjectList:
        result_json = self.get_json(siteId, biztpId, hintKeywords, event, month, showDetail)
        relstat_list = []
        for arr in result_json:
            relstat = RelKwdStatObject(arr)
            relstat_list.append(relstat)

        return relstat_list



from nevada.Common.Connector import *
from typing import List
import json

class BizmoneyObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.bizmoney = None if 'bizmoney' not in s else s['bizmoney']
        self.budgetLock = None if 'budgetLock' not in s else s['budgetLock']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.refundLock = None if 'refundLock' not in s else s['refundLock']

class BizmoneyCostObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.adjustedNonRefundableAmt = None if 'adjustedNonRefundableAmt' not in s else s['adjustedNonRefundableAmt']
        self.adjustedRefundableAmt = None if 'adjustedRefundableAmt' not in s else s['adjustedRefundableAmt']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.date = None if 'date' not in s else s['date']
        self.device = None if 'device' not in s else s['device']
        self.networkType = None if 'networkType' not in s else s['networkType']
        self.nonRefundableAmt = None if 'nonRefundableAmt' not in s else s['nonRefundableAmt']
        self.productCode = None if 'productCode' not in s else s['productCode']
        self.refundableAmt = None if 'refundableAmt' not in s else s['refundableAmt']

class Bizmoney:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    BizmoneyCostObjectList = List[BizmoneyCostObject]

    def get_biz_money_json(self):
        result = self.conn.get('/billing/bizmoney')
        return result

    def get_biz_money_list(self) -> BizmoneyObject:
        result_json = self.get_biz_money_json()
        result = BizmoneyObject(result_json)
        return result

    def get_biz_money_cost_json(self, statDt: str):
        result = self.conn.get('/billing/bizmoney/cost/' + statDt)
        return result

    def get_biz_money_cost_list(self, statDt: str) -> BizmoneyCostObjectList:
        result_json = self.get_biz_money_cost_json(statDt)
        cost_list = []
        for arr in result_json:
            cost = BizmoneyCostObject(arr)
            cost_list.append(cost)
        return cost_list



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class CreateStatReportObject:
    def __init__(self, reportTp, statDt):
        self.reportTp = reportTp
        self.statDt = statDt

class StatReportObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.downloadUrl = None if 'downloadUrl' not in s else s['downloadUrl']
        self.loginId = None if 'loginId' not in s else s['loginId']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.reportJobId = None if 'reportJobId' not in s else s['reportJobId']
        self.reportTp = None if 'reportTp' not in s else s['reportTp']
        self.statDt = None if 'statDt' not in s else s['statDt']
        self.status = None if 'status' not in s else s['status']
        self.updateTm = None if 'updateTm' not in s else s['updateTm']

class StatReport:  # 대용량 보고서
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    StatReportObjectList = List[StatReportObject]

    def get_stat_report_list(self) -> StatReportObjectList:
        result = self.conn.get('/stat-reports')
        stat_list = []
        for arr in result:
            stat = StatReportObject(arr)
            stat_list.append(stat)
        return stat_list

    def get_stat_report(self, reportJobId: str) -> StatReportObject:
        result = self.conn.get('/stat-reports/' + reportJobId)
        result = StatReportObject(result)
        return result

    def create_stat_report(self, CreateStatReportObject: CreateStatReportObject) -> StatReportObject:
        data = jsonpickle.encode(CreateStatReportObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)

        result = self.conn.post('/stat-reports', data_str)
        result = StatReportObject(result)
        return result

    def delete_stat_reports(self, reportJobId: str):
        self.conn.delete('/stat-reports/' + reportJobId)
        return True



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class CreateAdExtensionObject:
    def __init__(self, pcChannelId, mobileChannelId, ownerId, type, userLock):
        self.pcChannelId = pcChannelId
        self.mobileChannelId = mobileChannelId
        self.ownerId = ownerId
        self.schedule = None
        self.type = type
        self.userLock = userLock

class UpdateAdExtensionObject:
    def __init__(self, nccAdExtensionId, schedule=None, userLock = None):
        self.nccAdExtensionId = nccAdExtensionId
        self.schedule = schedule
        self.userLock = userLock

class AdExtensionObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.delFlag = None if 'delFlag' not in s else s['delFlag']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.inspectStatus = None if 'inspectStatus' not in s else s['inspectStatus']
        self.mobileChannelId = None if 'mobileChannelId' not in s else s['mobileChannelId']
        self.nccAdExtensionId = None if 'nccAdExtensionId' not in s else s['nccAdExtensionId']
        self.ownerId = None if 'ownerId' not in s else s['ownerId']
        self.pcChannelId = None if 'pcChannelId' not in s else s['pcChannelId']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.status = None if 'status' not in s else s['status']
        self.statusReason = None if 'statusReason' not in s else s['statusReason']
        self.type = None if 'type' not in s else s['type']
        self.userLock = None if 'userLock' not in s else s['userLock']


class AdExtension:  # 확장소재
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)
    AdExtensionObjectList = List[AdExtensionObject]
    IdList = List[str]
    ChangeFieldsList = List[str]

    def get_ad_extensions_list(self, ownerId: str) -> AdExtensionObjectList:
        result = self.conn.get('/ncc/ad-extensions', {'ownerId': ownerId})
        adext_list = []
        for arr in result:
            camp = AdExtensionObject(arr)
            adext_list.append(camp)
        return adext_list

    def get_ad_extensions_list_by_ids(self, ids: IdList) -> AdExtensionObjectList:
        ids = ",".join(ids)
        ids = {'ids': ids}
        result = self.conn.get('/ncc/ad-extensions', ids)
        adext_list = []
        for arr in result:
            camp = AdExtensionObject(arr)
            adext_list.append(camp)
        return adext_list

    def get_ad_extensions(self, adExtensionId: str) -> AdExtensionObject:
        result = self.conn.get('/ncc/ad-extensions/' + adExtensionId)
        result = AdExtensionObject(result)

        return result

    def create_ad_extensions(self, CreateAdExtensionObject: CreateAdExtensionObject) -> AdExtensionObject:
        data = jsonpickle.encode(CreateAdExtensionObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = data
        data_str = json.dumps(data_str)

        result = self.conn.post('/ncc/ad-extensions', data_str)
        result = AdExtensionObject(result)
        return result

    def update_ad_extensions(self, adExtensionId: str, fields: ChangeFieldsList,
                             UpdateAdExtensionObject: UpdateAdExtensionObject) -> AdExtensionObject:
        data = jsonpickle.encode(UpdateAdExtensionObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = data
        data_str = json.dumps(data_str)
        change_fields_list = ",".join(fields)
        query = {'fields': change_fields_list}
        result = self.conn.put('/ncc/ad-extensions/' + adExtensionId, data_str, query)
        result = AdExtensionObject(result)
        return result

    def delete_ad_extensions(self, adExtensionId: str):
        self.conn.delete('/ncc/ad-extensions/' + adExtensionId)
        return True



import json
import time
import hmac
import base64
import hashlib
import requests
import urllib.parse
from datetime import datetime

class CommonFunctions:

    @staticmethod
    def print_all_attr(obj: object):
        type_list = [type(True), type('str'), type(0), type(None), type({'0':0}), type(0.1),type([])]

        def print_all_attr_copy(obj: object, temp):
            for key in obj.__dict__.keys():
                if temp == 1:
                    print(' L  ', end='')
                elif temp == 2:
                    print('     L  ', end='')
                elif temp == 3:
                    print('         L  ', end='')

                print(key, ': ', end='')

                if type(obj.__getattribute__(key)) in type_list:
                    print(obj.__getattribute__(key))
                else:
                    print()
                    temp += 1
                    print_all_attr_copy(obj.__getattribute__(key), temp)
                    temp -= 1

        print_all_attr_copy(obj, 0)
        print()

    @staticmethod
    def dropna(input_dict):
        cleaned_dict = dict()
        for now in input_dict:
            if input_dict[now] != None:
                cleaned_dict.update({now: input_dict[now]})
        return cleaned_dict

    # def dropna(self, input_dict):
    #     cleaned_dict = dict()
    #     for now in input_dict:
    #         if type(input_dict[now])==type({'j':'son'}):
    #             temp = dict()
    #             for now2 in now:
    #                 if now[now2] != None:
    #                     temp.update({now2: now[now2]})
    #             cleaned_dict.update({now: temp})
    #         else:
    #             cleaned_dict.update({now: input_dict[now]})
    #     return cleaned_dict

class Connector:
    def __init__(self, base_url, api_key, secret_key, customer_id):
        self.base_url = base_url
        self.api_key = api_key
        self.secret_key = secret_key
        self.customer_id = customer_id

    def help(self):
        import Help
        help_message = Help.Connector
        print(help_message)
        return help_message

    def generate_signature(self, timestamp, method, path):
        sign = '{timestamp}.{method}.{path}'.format(timestamp=timestamp, method=method, path=path)
        signature = hmac.new(self.secret_key.encode(), sign.encode(), hashlib.sha256).digest() #.hexdigest()
        return base64.b64encode(signature).decode()

    def build_http_query(self, query):
        if query:
            query_list = []
            for key, value in query.items():
                if value != None:
                    if (type(value)==type([])) and len(value)!=1:
                        for i in value:
                            q = "{key}={value}".format(key=urllib.parse.quote_plus(key),value=urllib.parse.quote_plus(i))
                            query_list.append(q)
                    else:
                        q = "{key}={value}".format(key=urllib.parse.quote_plus(key),value=urllib.parse.quote_plus(value))
                        query_list.append(q)
            return '&'.join(query_list)
        else:
            return ''

    def get_header(self, method, uri):
        timestamp = self.get_timestamp()
        header = {}
        header['Content-Type'] = 'application/json; charset=UTF-8'
        header['X-Timestamp'] = str(timestamp)
        header['X-API-KEY'] = self.api_key
        header['X-Customer'] = str(self.customer_id)
        header['X-Signature'] = self.generate_signature(timestamp, method, uri)
        return header

    def get_transaction_id(self, headers):
        if "X-Transaction-ID" in headers:
            return headers["X-Transaction-ID"]
        else:
            return "unknown"

    def parse_response(self, response):
        if response:
            header = response.headers
            body = response.text
            transaction_id = self.get_transaction_id(header)
            json_body = json.loads(body)

            return {'transaction_id': transaction_id, 'json': json_body}

        return {}

    def get(self, uri, query={}):
        url = "{base_url}{uri}{query}{http_query}".format(
            base_url=self.base_url,
            uri=uri,
            query='' if query == {} else '?',
            http_query=self.build_http_query(query))
        headers = self.get_header('GET', uri)

        try:
            r = requests.get(url=url, headers=headers)
            response = self.parse_response(r)
            if not r.ok:
                print("Http status: {status_code}".format(status_code=r.status_code))
            return response['json']
        except:
            print("failed to request")

    def post(self, uri, data, query={}):
        url = "{base_url}{uri}{query}{http_query}".format(
            base_url=self.base_url,
            uri=uri,
            query='' if query == {} else '?',
            http_query=self.build_http_query(query))
        headers = self.get_header('POST', uri)
        try:
            r = requests.post(url=url, data=data, headers=headers)
            response = self.parse_response(r)
            if not r.ok:
                print("Http status: {status_code}".format(status_code=r.status_code))
            return response['json']
        except:
            print("failed to request")

    def put(self, uri, data, query={}):
        url = "{base_url}{uri}{query}{http_query}".format(
            base_url=self.base_url,
            uri=uri,
            query='' if query == {} else '?',
            http_query=self.build_http_query(query))

        headers = self.get_header('PUT', uri)

        try:
            r = requests.put(url=url, data=data, headers=headers)
            response = self.parse_response(r)
            if not r.ok:
                print("Http status: {status_code}".format(status_code=r.status_code))
            return response['json']
        except:
            print("failed to request")

    def delete(self, uri, query={}):
        url = "{base_url}{uri}{query}{http_query}".format(
            base_url=self.base_url,
            uri=uri,
            query='' if query == {} else '?',
            http_query=self.build_http_query(query))

        headers = self.get_header('DELETE', uri)

        try:
            r = requests.delete(url=url, headers=headers)
            response = self.parse_response(r)
            if not r.ok:
                print("Http status: {status_code}".format(status_code=r.status_code))
            return response['json']
        except:
            print("failed to request")

    def get_timestamp(self):
        return round(time.time() * 1000)

    def get_datetime(self):
        return datetime.now()

    def download(self, url, localpath):
        return None

    def null_dict(self, input_dict):
        real = dict()
        for now in input_dict:
            if input_dict[now] != None:
                real.update({now :input_dict[now]})
        return real



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class BusinessInfo:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.isMobileNaverLogin = None if 'isMobileNaverLogin' not in s else s['isMobileNaverLogin']
        self.isMobileNaverPay = None if 'isMobileNaverPay' not in s else s['isMobileNaverPay']
        self.isMobileNaverTalkTalk = None if 'isMobileNaverTalkTalk' not in s else s['isMobileNaverTalkTalk']
        self.isNaverLogin = None if 'isNaverLogin' not in s else s['isNaverLogin']
        self.isNaverPay = None if 'isNaverPay' not in s else s['isNaverPay']
        self.isNaverTalkTalk = None if 'isNaverTalkTalk' not in s else s['isNaverTalkTalk']
        self.isStoreFarm = None if 'isStoreFarm' not in s else s['isStoreFarm']
        self.mobileCertStatus = None if 'mobileCertStatus' not in s else s['mobileCertStatus']
        self.naAccountId = None if 'naAccountId' not in s else s['naAccountId']
        self.naAccountType = None if 'naAccountType' not in s else s['naAccountType']
        self.originalPath = None if 'originalPath' not in s else s['originalPath']
        self.site = None if 'site' not in s else s['site']
        self.thumbnailPath = None if 'thumbnailPath' not in s else s['thumbnailPath']
        self.useNaverPayNaScript = None if 'useNaverPayNaScript' not in s else s['useNaverPayNaScript']
        self.useSaNaScript = None if 'useSaNaScript' not in s else s['useSaNaScript']
        self.useStoreFarmNaScript = None if 'useStoreFarmNaScript' not in s else s['useStoreFarmNaScript']

class UpdateBusinessChannelObject:
    def __init__(self, nccBusinessChannelId, site_url, name):
        self.businessInfo = {'site' : site_url}
        self.channelTp = 'SITE'
        self.inspectRequestMsg = None
        self.name = name
        self.nccBusinessChannelId = nccBusinessChannelId

class CreateBusinessChannelObject:
    def __init__(self, businessInfo, channelTp, name, inspectReqeustMsg=None):
        self.businessInfo = businessInfo#{'site':'github.com/taegyumin'}#
        self.channelTp = channelTp
        self.inspectRequestMsg = inspectReqeustMsg
        self.name = name

class BusinessChannelObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.adultStatus = None if 'adultStatus' not in s else s['adultStatus']
        self.blackStatus = None if 'blackStatus' not in s else s['blackStatus']
        self.businessInfo = None if 'businessInfo' not in s else BusinessInfo(s['businessInfo'])
        self.channelKey = None if 'channelKey' not in s else s['channelKey']
        self.channelTp = None if 'channelTp' not in s else s['channelTp']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.delFlag = None if 'delFlag' not in s else s['delFlag']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.enabled = None if 'enabled' not in s else s['enabled']
        self.firstChargeTm = None if 'firstChargeTm' not in s else s['firstChargeTm']
        self.inspectTm = None if 'inspectTm' not in s else s['inspectTm']
        self.mobileInspectStatus = None if 'mobileInspectStatus' not in s else s['mobileInspectStatus']
        self.name = None if 'name' not in s else s['name']
        self.nccBusinessChannelId = None if 'nccBusinessChannelId' not in s else s['nccBusinessChannelId']
        self.pcInspectStatus = None if 'pcInspectStatus' not in s else s['pcInspectStatus']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.status = None if 'status' not in s else s['status']
        self.statusReason = None if 'statusReason' not in s else s['statusReason']


class BusinessChannel:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    BusinessChannelObjectList = List[BusinessChannelObject]
    BusinessChannelIdList = List[str]

    def get_business_channel_json(self, businessChannelId: str):
        result = self.conn.get('/ncc/channels/' + businessChannelId)
        return result

    def get_business_channel_list(self, businessChannelId: str) -> BusinessChannelObject:
        result = self.get_business_channel_json(businessChannelId)
        result = BusinessChannelObject(result)
        return result

    def get_business_channel_all_json(self):
        result = self.conn.get('/ncc/channels')
        return result

    def get_business_channel_all_list(self) -> BusinessChannelObjectList:
        result = self.get_business_channel_all_json()
        business_channel_list = []
        for arr in result:
            channel = BusinessChannelObject(arr)
            business_channel_list.append(channel)
        return business_channel_list

    def get_business_channel_by_type_json(self, channelTp: str):
        result = self.conn.get('/ncc/channels', {'channelTp': channelTp})
        return result

    def get_business_channel_by_type_list(self, channelTp: str) -> BusinessChannelObjectList:
        result = self.get_business_channel_by_type_json(channelTp)
        business_channel_list = []
        for arr in result:
            channel = BusinessChannelObject(arr)
            business_channel_list.append(channel)
        return business_channel_list

    def get_business_channel_by_ids_json(self, ids: BusinessChannelIdList):
        ids = ",".join(ids)
        query = {'ids': ids}
        result = self.conn.get('/ncc/channels', query)
        return result

    def get_business_channel_by_ids_list(self, ids: BusinessChannelIdList) -> BusinessChannelObjectList:
        result = self.get_business_channel_by_ids_json(ids)
        business_channel_list = []
        for arr in result:
            channel = BusinessChannelObject(arr)
            business_channel_list.append(channel)
        return business_channel_list

    def create_business_channel(self, CreateBusinessChannelObject: CreateBusinessChannelObject) -> BusinessChannelObject:
        data = jsonpickle.encode(CreateBusinessChannelObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/ncc/channels', data_str)
        result = BusinessChannelObject(result)
        return result

    def update_business_channel(self, fields,
                                UpdateBusinessChannelObject: UpdateBusinessChannelObject) -> BusinessChannelObject:
        data = jsonpickle.encode(UpdateBusinessChannelObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.put('/ncc/channels', data_str, fields)
        result = BusinessChannelObject(result)
        return result

    def delete_business_channel(self, businessChannelId: str):
        self.conn.delete('/ncc/channels/' + businessChannelId)
        return True

    def delete_business_channel_by_ids(self, ids: BusinessChannelIdList):
        ids = ",".join(ids)
        query = {'ids': ids}
        self.conn.delete('/ncc/channels', query)
        return True


from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class CreateMasterReportObject:
    def __init__(self, item, fromTime):
        self.item = item
        self.fromTime = fromTime

class MasterReportObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.clientCustomerId = None if 'clientCustomerId' not in s else s['clientCustomerId']
        self.downloadUrl = None if 'downloadUrl' not in s else s['downloadUrl']
        self.fromTime = None if 'fromTime' not in s else s['fromTime']
        self.id = None if 'id' not in s else s['id']
        self.item = None if 'item' not in s else s['item']
        self.managerCustomerId = None if 'managerCustomerId' not in s else s['managerCustomerId']
        self.managerLoginId = None if 'managerLoginId' not in s else s['managerLoginId']
        self.registTime = None if 'registTime' not in s else s['registTime']
        self.status = None if 'status' not in s else s['status']
        self.updateTime = None if 'updateTime' not in s else s['updateTime']

class MasterReport:  # 광고정보일괄다운로드탭
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    MasterReportObjectList = List[MasterReportObject]

    def get_master_report_list(self) -> MasterReportObjectList:
        result = self.conn.get('/master-reports')
        mreport_list = []
        for arr in result:
            mreport = MasterReportObject(arr)
            mreport_list.append(mreport)
        return mreport_list

    def get_master_report_by_id(self, id: str) -> MasterReportObject:
        result = self.conn.get('/master-reports/' + id)
        result = MasterReportObject(result)
        return result

    def create_master_report(self, CreateMasterReportObject: CreateMasterReportObject) -> MasterReportObject:
        data = jsonpickle.encode(CreateMasterReportObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/master-reports', data_str)
        result = MasterReportObject(result)
        return result

    def delete_master_report_all(self):
        self.conn.delete('/master-reports')
        return True

    def delete_master_report_by_id(self, id: str):
        self.conn.delete('/master-reports', {'id': id})
        return True



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class AdFieldObject:
    def __init__(self, json_def=None):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.pc_display = None if 'pc' not in s else self.pc_display_easy(s['pc'])
        self.pc_final = None if 'pc' not in s else self.pc_final_easy(s['pc'])
        self.mobile_display = None if 'mobile' not in s else self.mobile_display_easy(s['mobile'])
        self.mobile_final = None if 'mobile' not in s else self.mobile_final_easy(s['mobile'])
        self.headline = None if 'headline' not in s else s['headline']
        self.description = None if 'description' not in s else s['description']

    def pc_final_easy(self, pc):
        return pc['final']

    def pc_display_easy(self, pc):
        return pc['display']

    def mobile_final_easy(self, mobile):
        return mobile['final']

    def mobile_display_easy(self, mobile):
        return mobile['display']

class UpdateAdObject:
    def __init__(self, adAttr, nccAdId):
        self.adAttr = adAttr
        self.inspectRequestMsg = None
        self.nccAdId = nccAdId
        self.userLock = None

class CreateAdObject:
    def __init__(self, adObject, nccAdgroupId, type):
        self.ad = adObject
        self.inspectRequestMsg = None
        self.nccAdgroupId = nccAdgroupId
        self.type = type
        self.userLock = None

class AdObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.ad = None if 'ad' not in s else AdFieldObject(s['ad'])
        self.adattr = None if 'adattr' not in s else s['adattr']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.inspectRequestMsg = None if 'inspectRequestMsg' not in s else s['inspectRequestMsg']
        self.inspectStatus = None if 'inspectStatus' not in s else s['inspectStatus']
        self.nccAdId = None if 'nccAdId' not in s else s['nccAdId']
        self.nccAdgroupId = None if 'nccAdgroupId' not in s else s['nccAdgroupId']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.status = None if 'status' not in s else s['status']
        self.statusReason = None if 'statusReason' not in s else s['statusReason']
        self.type = None if 'type' not in s else s['type']
        self.userLock = None if 'userLock' not in s else s['userLock']

class Ad:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    AdIdList = List[str]
    AdObjectList = List[AdObject]
    ChangeFieldsList = List[str]

    def get_ad_by_ad_id(self, adId: str, json=False) -> AdObject:
        result = self.conn.get('/ncc/ads/' + adId)
        if json==False:
            result = AdObject(result)
            return result
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def get_ad_by_adgroup_id(self, nccAdGroupId: str, json=False) -> AdObjectList:
        result = self.conn.get('/ncc/ads', {'nccAdgroupId': nccAdGroupId})
        if json==False:
            adobj_list = []
            for arr in result:
                ad_obj = AdObject(arr)
                adobj_list.append(ad_obj)
            return adobj_list
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def get_ad_by_ad_ids(self, ids: AdIdList, json=False) -> AdObjectList:
        ids = ",".join(ids)
        ids = {'ids': ids}
        result = self.conn.get('/ncc/ads', ids)
        if json==False:
            ad_obj_list = []
            for arr in result:
                ad_obj = AdObject(arr)
                ad_obj_list.append(ad_obj)
            return ad_obj_list
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def create_ad(self, CreateAdObject: CreateAdObject) -> AdObject:
        data = jsonpickle.encode(CreateAdObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = data
        data_str = json.dumps(data_str)
        result = self.conn.post('/ncc/ads', data_str)
        result = AdObject(result)
        return result

    def update_ad(self, adId: str, fields: ChangeFieldsList, UpdateAdObject: UpdateAdObject) -> AdObject:
        change_fields_list = ",".join(fields)
        query = {'fields': change_fields_list}
        data = jsonpickle.encode(UpdateAdObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = data
        data_str = json.dumps(data_str)
        result = self.conn.put('/ncc/ads/' + adId, data_str, query)
        result = AdObject(result)
        return result

    def delete_ad(self, adId: str):
        self.conn.delete('/ncc/ads/' + adId)
        return True

    def copy_ad(self, adId: str, targetAdGroupId: str, userLock: bool) -> AdObject:
        query = {'ids': adId, 'targetAdgroupId': targetAdGroupId, 'userLock': userLock}
        result = self.conn.put('/ncc/ads', None, query)
        result = AdObject(result)
        return result


from nevada.Common.Connector import *
from typing import List
import json

class StatDataObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.avgRnk = None if 'avgRnk' not in s else s['avgRnk']
        self.ccnt = None if 'ccnt' not in s else s['ccnt']
        self.clkCnt = None if 'clkCnt' not in s else s['clkCnt']
        self.cpc = None if 'cpc' not in s else s['cpc']
        self.ctr = None if 'ctr' not in s else s['ctr']
        self.dateEnd = None if 'dateEnd' not in s else s['dateEnd']
        self.dateStart = None if 'dateStart' not in s else s['dateStart']
        self.drtCrto = None if 'drtCrto' not in s else s['drtCrto']
        self.impCnt = None if 'impCnt' not in s else s['impCnt']
        self.salesAmt = None if 'salesAmt' not in s else s['salesAmt']

class SummaryObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.dateEnd = None if 'dateEnd' not in s else s['dateEnd']
        self.dateStart = None if 'dateStart' not in s else s['dateStart']

class StatTypeObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.clkCnt = None if 'clkCnt' not in s else s['clkCnt']
        self.drtCrto = None if 'drtCrto' not in s else s['drtCrto']
        self.salesAmt = None if 'salesAmt' not in s else s['salesAmt']
        self.schKeyword = None if 'schKeyword' not in s else s['schKeyword']

class StatObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.data = None if 'data' not in s else self.match_data(s['data'])  # list
        self.summary = None if 'data' not in s else SummaryObject(s['data'])

    def match_data(self, s):
        stat_list = []
        for arr in s:
            stat = StatDataObject(arr)
            stat_list.append(stat)
        return stat_list

class Stat:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    StatIdList = List[str]

    def get_stat_by_id(self, id: str, fields: str, timeRange: str, dataPreset: str = None, timeIncrement: str = None,
                       breakdown: str = None) -> StatObject:
        query = {'id': id, 'fields': fields, 'timeRange': timeRange, 'dataPreset': dataPreset,
                 'timeIncrement': timeIncrement, 'breakdown': breakdown}
        result = self.conn.get('/stats', query)
        result = StatObject(result)
        return result

    def get_stat_by_ids(self, ids: StatIdList, fields: str, timeRange: str, dataPreset: str = None,
                        timeIncrement: str = None, breakdown: str = None) -> StatObject:
        query = {'ids': ids, 'fields': fields, 'timeRange': timeRange, 'dataPreset': dataPreset,
                 'timeIncrement': timeIncrement, 'breakdown': breakdown}
        result = self.conn.get('/stats', query)
        result = StatObject(result)
        return result

    def get_stat_by_type(self, id: str, statType: str) -> StatTypeObject:
        query = {'id': id, 'statType': statType}
        result = self.conn.get('/stats', query)
        result = StatTypeObject(result)
        return result



import sys
from nevada.API.AdKeyword import *
from nevada.API.Adgroup import *
from nevada.API.Ad import *
from nevada.API.Label import *
from nevada.Common.Connector import *
from nevada.API.LabelRef import *

if __name__=="__main__":
    base_url = 'https://api.naver.com'
    api_key = '010000000006b395250f1116b4a4e2c817ec0c1ab5d2aadf3911ee4494e33c266ace517843'
    secret_key = 'AQAAAAAGs5UlDxEWtKTiyBfsDBq150HUUna4ueVv0LLF6A3r4w=='
    customer_id = 1810030

    # base_url = 'https://api.naver.com'
    # api_key = "01000000007705c93bf3d4717735ec919410620b09be66dba57008ea9ebd5c689cb34f9b03"  # 변경하세요.
    # secret_key = "AQAAAAB3Bck789RxdzXskZQQYgsJSgvA+JzNVuO1lfU2x5/4bA=="  # 변경하세요.
    # customer_id = 1839303  # 변경하세요.

    # result_list = label.get_label_list()
    # for i in result_list:
    #     CommonFunctions.print_all_attr(i)  # from nevada.Common.Connector import * 를 해줘야 함.

    #lbl-a001-00-000000000106050
    lr = LabelRef(base_url=base_url, api_key=api_key, secret_key=secret_key, customer_id=customer_id)

    result = lr.update_label_ref(editTm='2020-02-10T03:14:52.000Z', customerId=1810030, enable=False, nccLabelId='lbl-a001-00-000000000106050',refId='nad-a001-01-000000086037429', refTp='AD', regTm='2020-02-10T02:48:38.000Z', format=True)
    for i in result:
        CommonFunctions.print_all_attr(i)

    #adgroup = Adgroup(base_url=base_url, api_key=api_key, secret_key=secret_key, customer_id=customer_id)
    #adgroup.get_adgroup_by_campaign(nccCampaignId='cmp-a001-01-000000002696103', baseSearchId='grp-a001-03-000000014209115', recordSize=1, selector='NEXT')
    #cmp-a001-01-000000002696103
    #cmp-a001-03-000000002696246

    """
    #애드(소재) 소재고유번호를 통해 리스트 받아오기
    tt = ad.get_ad_list_by_ids('nad-a001-01-000000009598016') pprint.pprint(tt[0].nccAdId)

    애드그룹고유번호를 통해 리스트 받아오기
    tt = ad.get_ad_list('grp-a001-01-000000002412336') pprint.pprint(tt[0].ad.pc)

    소재고유번호를 통해 소재정보 받아오기
    tt = ad.get_ad('nad-a001-01-000000009598016') pprint.pprint(tt.nccAdgroupId)

    소재등록하기
    filed_obj = AdFieldObject() filed_obj.description = "이것은 에이피아이 테스트의 일종으로 테스트입니다."
    filed_obj.headline = "에이피아이 에드클라우드"
    filed_obj.pc = filed_obj.make_pc_easy('http://www.naver.com')
    filed_obj.mobile = filed_obj.make_mobile_easy('http://www.naver.com')

    add_obj = CreateAdObject(filed_obj, 'grp-a001-01-000000002412336', 'TEXT_45')

    return_obj = ad.create_ad(add_obj)

    소재 수정하기
    filed_obj = AdFieldObject()
    filed_obj.description = "이것은 에이피아이 테스트의 일종으로 테스트"
    filed_obj.headline = "에이피아이 에드클라우드"
    filed_obj.pc = filed_obj.make_pc_easy('http://www.naver.com')
    filed_obj.mobile = filed_obj.make_mobile_easy('http://www.naver.com')

    update_obj = UpdateAdObject(filed_obj,'nad-a001-01-000000010072369')
    update_obj.userLock = 1 ad.update_ad('nad-a001-01-000000010072369', 'userLock', update_obj)

    소재 복사
    ad.copy_ad('nad-a001-01-000000009598016', 'grp-a001-01-000000002548182', '0')

    소재 삭제
    ad.delete_ad('nad-a001-01-000000010072402')
    """




#     businessInfo = BusinessInfo({
#   "site": "http://www.naver.com",
#   "isNaverLogin": 0,
#   "isMobileNaverLogin": 0,
#   "naAccountId": "",
#   "naAccountType": 0,
#   "useNaverPayNaScript": 0,
#   "useStoreFarmNaScript": 0,
#   "isNaverPay": 0,
#   "isMobileNaverPay": 0,
#   "useSaNaScript": 0,
#   "mobileCertStatus": 20,
#   "isStoreFarm": 0,
#   "thumbnailPath": "/preview_img/ncc_image_capture/201606/95x71_67032860-345a-11e6-b089-a911737c8e1d.jpg",
#   "originalPath": "/preview_img/ncc_image_capture/201606/67032860-345a-11e6-b089-a911737c8e1d.jpg"
# })

    # new_bc = CreateBusinessChannelObject(businessInfo, channelTp='SITE', inspectReqeustMsg=None, name='JunhoSong')
    # print(len(bc.get_business_channel_all_json()))
    # bc.create_business_channel(new_bc)
    # print(len(bc.get_business_channel_all_json()))


    # label = Label(base_url=base_url, api_key=api_key, secret_key=secret_key, customer_id=customer_id)
    # for i in label.get_label_list():
    #     print(i.customerId, i.color, i.editTm, i.name, i.nccLabelId, i.regTm)

    # est = Estimate(base_url=base_url, api_key=api_key, secret_key=secret_key, customer_id=customer_id)
    # obj = [GetPerformanceBulkObject(device='PC', keywordplus=False, keyword = '스테인레스빨대', bid = 100)]
    # est.get_performance_bulk_json(obj)

    # label = Label(base_url=base_url, api_key=api_key, secret_key=secret_key, customer_id=customer_id)
    # result_list = label.get_label_list()
    # for result in result_list:
    #     CommonFunctions.print_all_attr(result)


    #1810030 #E65050 None RED lbl-a001-00-000000000106050 2020-02-10T02:48:38.000Z
    #1810030 #E65050 2020-02-10T02:50:34.000Z PINK lbl-a001-00-000000000106050 2020-02-10T02:48:38.000Z

    # 1810030  # E65050 2020-02-10T02:50:34.000Z PINK lbl-a001-00-000000000106050 2020-02-10T02:48:38.000Z
    # 1810030  # E6A050 None label-2 LABEL-2 None
    # 1810030  # CCCC04 None label-3 LABEL-3 None
    # 1810030  # 5DD47D None label-4 LABEL-4 None
    # 1810030  # 1ABA3D None label-5 LABEL-5 None
    # 1810030  # 4887E0 None label-6 LABEL-6 None
    # 1810030  # 6C58C7 None label-7 LABEL-7 None
    # 1810030  # CF81D6 None label-8 LABEL-8 None
    # 1810030  # 8C8C9D None label-9 LABEL-9 None
    # 1810030  # FF5959 None label-10 LABEL-10 None




    # estimate = Estimate(base_url=base_url, api_key=api_key, secret_key=secret_key, customer_id=customer_id)
    #
    # obj1 = GetPerformanceBulkObject(device='BOTH', keywordplus=False, keyword='종이빨대', bid=100)
    # obj2 = GetPerformanceBulkObject(device='BOTH', keywordplus=False, keyword='종이빨대', bid=200)
    # obj3 = GetPerformanceBulkObject(device='BOTH', keywordplus=False, keyword='종이빨대', bid=300)
    # obj = [obj1,obj2,obj3]
    # result = estimate.get_performance_many_json(GetPerformanceBulkObjectList=obj)
    # print(result)

    #입찰가:
    #매체구분: PC/모바일, PC, 모바일
    #키워드확장: ?

    #키워드 string keyword 스테인레스빨대 NULL
    # 입찰가 int bid [100,200,300,400,500] or 100 NULL
    # 매체구분 string device 'PC','MOBILE','BOTH' 'BOTH'
    #키워드_확장 적용/미적용 boolean keyword_expansion True/False None(Default value)

    # device = 'PC'
    # period = 'DAY'
    # items = ['종이빨대','스테인레스빨대']

    # GetExposureMinimumBid(device, period, items)
    # keyword = '스테인레스빨대'
    # bid = [100,200,300,400,500]

    # ms = MasterReport(base_url, api_key, secret_key, customer_id)
    # m = ms.get_master_report_list()
    # print(m[0].managerLoginId)

    # ad = Ad(base_url, api_key, secret_key, customer_id)
    # tt = ad.get_ad_list_by_ids(['nad-a001-01-000000009598016'])
    # print(tt)

    # key_and_position = KeyAndPositionObject('빨대', '1')
    # medi = GetAvgPositionBidObject('PC', key_and_position)
    # result = estimate.get_median_bid_json('keyword', medi)
    # print(result)



def print_all_attr(obj: object):
    def print_all_attr_copy(obj: object, temp):
        for key in obj.__dict__.keys():
            if temp == 1:
                print(' L ', end='')
            if temp == 2:
                print('    L ', end='')
            print(key, ': ', end='')
            if (type(obj.__getattribute__(key)) == type('str')) or (type(obj.__getattribute__(key)) == type(0)):
                print(obj.__getattribute__(key))
            else:
                print()
                temp += 1
                print_all_attr_copy(obj.__getattribute__(key), temp)
                temp -= 1
    print_all_attr_copy(obj, 0)


class Address:
    def __init__(self, postal, location):
        self.postal = postal
        self.location = location

class Contact:
    def __init__(self, phone_number, email, adress):
        self.phone_number = phone_number
        self.email = email
        self.adress = adress
class Persona:
    def __init__(self, name: str, age: int, contact: Contact):
        self.name = name
        self.age = age
        self.contact = contact

address = Address('02831','서울시 성북구 성북로4길 52')
contact = Contact('01074334271', 'minimax@snu.ac.kr', address)
persona = Persona('Taegyu Min', 24, contact)

print_all_attr(persona)


from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class UpdateIpExclusionObject:
    def __init__(self, filterIp, ipFilterId, memo):
        self.filterIp = filterIp
        self.ipFilterId = ipFilterId
        self.memo = memo

class CreateIpExclusionObject:
    def __init__(self, filterIp, memo):
        self.filterIp = filterIp
        self.memo = memo

class IpExclusionObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.filterIp = None if 'filterIp' not in s else s['filterIp']
        self.ipFilterId = None if 'ipFilterId' not in s else s['ipFilterId']
        self.memo = None if 'memo' not in s else s['memo']
        self.regTm = None if 'regTm' not in s else s['regTm']

class IpExclusion:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    ExclusionIdList = List[str]

    def get_ip_exclusion_json(self):
        result = self.conn.get('/tool/ip-exclusions')
        return result

    def get_ip_exclusion_list(self):
        result_list = self.get_ip_exclusion_json()
        ip_exclusion_list = []
        for arr in result_list:
            ipex = IpExclusionObject(arr)
            ip_exclusion_list.append(ipex)
        return ip_exclusion_list

    def create_ip_exclusion(self, filterIp, memo) -> IpExclusionObject:
        data = jsonpickle.encode(CreateIpExclusionObject(filterIp, memo), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/tool/ip-exclusions', data_str)
        result = IpExclusionObject(result)
        return result

    def update_ip_exclusion(self, filterIp, ipFilterId, memo) -> UpdateIpExclusionObject:
        data = jsonpickle.encode(UpdateIpExclusionObject(filterIp, ipFilterId, memo), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.put('/tool/ip-exclusions', data_str)
        result = IpExclusionObject(result)
        return result

    def delete_ip_exclusion(self, id: str):
        result = self.conn.delete('/tool/ip-exclusions/' + id)
        result = IpExclusionObject(result)
        return result

    def delete_ip_exclusion_many(self, id_array: ExclusionIdList):
        query = {'ids':id_array}
        self.conn.delete('/tool/ip-exclusions', query)
        return True



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class KeyAndPositionObject:
    def __init__(self, key, position):
        self.key = key
        self.position = position

class GetAvgPositionBidObject:
    def __init__(self, device, KeyAndPositonObject):
        self.device = device
        self.items = KeyAndPositonObject

class GetExposureMiniBidObject:
    def __init__(self, device, period, keys):
        self.device = device
        self.period = period
        self.items = keys

class GetMedianBidObject:
    def __init__(self, device, period, keys):
        self.device = device
        self.period = period
        self.items = keys

class GetPerformanceObject:
    def __init__(self, device, keywordplus, key, bids):
        self.device = device
        self.keywordplus = keywordplus
        self.key = key
        self.bids = bids

class GetPerformanceBulkObject:
    def __init__(self, device, keywordplus, keyword, bid):
        self.device = device
        self.keywordplus = keywordplus
        self.keyword = keyword
        self.bid = bid

class EstimateAvgObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.bid = None if 'bid' not in s else s['bid']
        self.keyword = None if 'keyword' not in s else s['keyword']
        #self.nccKeywordId = None if 'nccKeywordId' not in s else s['nccKeywordId']
        self.position = None if 'position' not in s else s['position']

class EstimateExposureMiniObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.bid = None if 'bid' not in s else s['bid']
        self.keyword = None if 'keyword' not in s else s['keyword']

class EstimateMedianObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.bid = None if 'bid' not in s else s['bid']
        self.keyword = None if 'keyword' not in s else s['keyword']

class EstimatePerformanceObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.bid = None if 'bid' not in s else s['bid']
        self.clicks = None if 'clicks' not in s else s['clicks']
        self.cost = None if 'cost' not in s else s['cost']
        self.impressions = None if 'impressions' not in s else s['impressions']
        self.cost_per_click = int(self.cost / self.clicks)

class EstimatePerformanceBulkObject:
    def __init__(self, device, keywordplus, keyword, bid, clicks, impressions, cost):
        self.device = device
        self.keywordplus = keywordplus
        self.keyword = keyword
        self.bid = bid
        self.clicks = clicks
        self.impressions = impressions
        self.cost = cost
        self.cost_per_click = int(self.cost / self.clicks)

class Estimate:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    EstimateAvgObjectList = List[EstimateAvgObject]
    EstimateMedianObjectList = List[EstimateMedianObject]
    EstimateExposureMiniObjectList = List[EstimateExposureMiniObject]
    EstimatePerformanceObjectList = List[EstimatePerformanceObject]
    GetPerformanceObjectList = List[GetPerformanceObject]
    GetPerformanceBulkObjectList = List[GetPerformanceBulkObject]

    def get_avg_position_bid_json(self, type, device, key_and_position_list):
        temp = []
        for key_and_position in key_and_position_list:
             temp.append(KeyAndPositionObject(key_and_position[0],key_and_position[1]))
        data = jsonpickle.encode(GetAvgPositionBidObject(device, temp), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/estimate/average-position-bid/' + type, data_str)
        result = result['estimate']
        return result

    def get_avg_position_bid_list(self, type, device, key_and_position_list) -> EstimateAvgObjectList:
        result_json = self.get_avg_position_bid_json(type, device, key_and_position_list)
        estimate_list = []
        for arr in result_json:
            estimate = EstimateAvgObject(arr)
            estimate_list.append(estimate)
        return estimate_list

    def get_exposure_mini_bid_json(self, type: str, device, period, keys):
        data = jsonpickle.encode(GetExposureMiniBidObject(device, period, keys), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/estimate/exposure-minimum-bid/' + type, data_str)
        result = result['estimate']
        return result

    def get_exposure_mini_bid_list(self, type: str, device, period, keys) -> EstimateExposureMiniObjectList:
        result_json = self.get_exposure_mini_bid_json(type, device, period, keys)
        estimate_list = []
        for arr in result_json:
            estimate = EstimateExposureMiniObject(arr)
            estimate_list.append(estimate)
        return estimate_list

    def get_median_bid_json(self, type: str, device, period, keys):
        data = jsonpickle.encode(GetMedianBidObject(device, period, keys), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/estimate/median-bid/' + type, data_str)
        result = result['estimate']
        return result

    def get_median_bid_list(self, type: str, device, period, keys) -> EstimateMedianObjectList:
        result_json = self.get_median_bid_json(type, device, period, keys)
        estimate_list = []
        for arr in result_json:
            estimate = EstimateMedianObject(arr)
            estimate_list.append(estimate)
        return estimate_list

    def get_performance_json(self, type: str, device, keywordplus, key, bids):
        data = jsonpickle.encode(GetPerformanceObject(device, keywordplus, key, bids), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        query = {'items': data_str}
        result = self.conn.post('/estimate/performance/' + type, data_str, query=query)
        result = result['estimate']
        return result

    def get_performance_list(self, type: str, device, keywordplus, key, bids) -> EstimatePerformanceObjectList:
        result_json = self.get_performance_json(type, device, keywordplus, key, bids)
        estimate_list = []
        for arr in result_json:
            estimate = EstimatePerformanceObject(arr)
            estimate_list.append(estimate)
        return estimate_list

    # def get_performance_many_json(self, type: str, GetPerformanceObjectList: GetPerformanceObjectList):
    #     data = jsonpickle.encode(GetPerformanceObjectList, unpicklable=False)
    #     data = json.loads(data)
    #     #data = CommonFunctions.dropna(data)
    #     data_str = json.dumps(data)
    #     print('data_str: ',data_str)
    #     result = self.conn.post('/estimate/performance/' + type, data_str)
    #     print('result: ',result)
    #     result = result['estimate']
    #     return result

    def get_performance_bulk_json(self, type: str, GetPerformanceBulkObjectList: GetPerformanceBulkObjectList):
        data = jsonpickle.encode(GetPerformanceBulkObjectList, unpicklable=False)
        data = json.loads(data)
        #data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        print(data_str)
        result = self.conn.post('/estimate/performance-bulk', data_str)
        result = result['estimate']
        return result

    def get_performance_bulk_list(self, type: str, GetPerformanceObjectList: GetPerformanceObjectList):
        result_json = self.get_performance_bulk_json(type, GetPerformanceObjectList)
        estimate_list = []
        for arr in result_json:
            estimate = EstimatePerformanceObject(arr)
            estimate_list.append(estimate)
        return estimate_list



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class CreateAdKeywordObject:
    def __init__(self, keyword):
        self.bidAmt = None
        self.customerId = None
        self.keyword = keyword
        self.useGroupBidAmt = None
        self.userLock = None

class UpdateAdKeywordObject:
    def __init__(self, nccAdgroupId, nccKeywordId):
        self.bidAmt = None
        self.links = None
        self.nccAdgroupId = nccAdgroupId
        self.nccKeywordId = nccKeywordId
        self.useGroupBidAmt = None
        self.userLock = None

class AdKeywordObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.bidAmt = None if 'bidAmt' not in s else s['bidAmt']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.inspectStatus = None if 'inspectStatus' not in s else s['inspectStatus']
        self.keyword = None if 'keyword' not in s else s['keyword']
        self.nccAdgroupId = None if 'nccAdgroupId' not in s else s['nccAdgroupId']
        self.nccCampaignId = None if 'nccCampaignId' not in s else s['nccCampaignId']
        self.nccKeywordId = None if 'nccKeywordId' not in s else s['nccKeywordId']
        self.nccQi = None if 'nccQi' not in s else s['nccQi']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.status = None if 'status' not in s else s['status']
        self.statusReason = None if 'statusReason' not in s else s['statusReason']
        self.useGroupBidAmt = None if 'useGroupBidAmt' not in s else s['useGroupBidAmt']
        self.userLock = None if 'userLock' not in s else s['userLock']


class AdKeyword:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    AdKeywordList = List[AdKeywordObject]
    AdKeywordIdList = List[str]

    def get_adkeyword_list_by_label_id(self, nccLabelId: str) -> AdKeywordList:
        query = {'nccLabelId': nccLabelId}
        result = self.conn.get('/ncc/keywords', query)

        adkeyword_list = []
        for arr in result:
            keyword = AdKeywordObject(arr)
            adkeyword_list.append(keyword)

        return adkeyword_list

    def get_adkeyword_list_by_ids(self, ids: AdKeywordIdList) -> AdKeywordList:
        ids = ",".join(ids)
        query = {'ids': ids}
        result = self.conn.get('/ncc/keywords', query)

        adkeyword_list = []
        for arr in result:
            keyword = AdKeywordObject(arr)
            adkeyword_list.append(keyword)

        return adkeyword_list

    def get_adkeyword_list_by_group_id(self, nccAdgroupId: str = None, baseSearchId: str = None,
                                       recordSize: int = None, selector: str = None) -> AdKeywordList:

        query = {'nccAdgroupId': nccAdgroupId, 'baseSearchId': baseSearchId, 'recordSize': recordSize,
                 'selector': selector}
        result = self.conn.get('/ncc/keywords', query)

        adkeyword_list = []
        for arr in result:
            keyword = AdKeywordObject(arr)
            adkeyword_list.append(keyword)

        return adkeyword_list

    def get_adkeyword(self, nccKeywordId) -> AdKeywordObject:
        result = self.conn.get('/ncc/keywords/' + nccKeywordId)
        result = AdKeywordObject(result)
        return result

    def create_adkeyword(self, nccAdgroupId, CreateAdKeywordObject) -> AdKeywordObject:
        data = jsonpickle.encode(CreateAdKeywordObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data = [data]
        data_str = json.dumps(data)

        result = self.conn.post('/ncc/keywords', data_str, {'nccAdgroupId': nccAdgroupId})
        result = AdKeywordObject(result)
        return result

    def update_adkeyrword(self, nccKeywordId, fields, UpdateAdKeywordObject) -> AdKeywordObject:
        data = jsonpickle.encode(UpdateAdKeywordObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)

        query = {'fields': fields}

        result = self.conn.put('/ncc/keywords/' + nccKeywordId, data_str, query)
        result = AdKeywordObject(result)
        return result

    def delete_adkeyword(self, nccKeywordId: str):
        self.conn.delete('/ncc/keywords/' + nccKeywordId)
        return True

    def delete_adkeyword_many(self, ids: AdKeywordIdList):
        ids = ",".join(ids)
        query = {'ids': ids}
        self.conn.delete('/ncc/keywords', query)


from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class CampaignAddObject:
    def __init__(self, customerId, campaignTp, name):
        self.customerId = customerId
        self.campaignTp = campaignTp
        self.dailyBudget = None
        self.deliveryMethod = None
        self.name = name
        self.periodEndDt = None
        self.periodStartDt = None
        self.trackingMode = None
        self.trackingUrl = None
        self.useDailyBudget = None
        self.usePeriod = None
        self.userLock = None

class CampaignUpdateObject:
    def __init__(self, lock, budget =None, period=None):
        if lock != None:
            self.userLock = bool(lock)
        if budget != None:
            self.useDailyBudget = bool(budget)
        if period != None:
            self.usePeriod = bool(period)

class CampaignObject():

    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)

        s = json_def

        self.campaignTp = None if 'campaignTp' not in s else s['campaignTp']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.dailyBudget = None if 'dailyBudget' not in s else s['dailyBudget']
        self.delFlag = None if 'delFlag' not in s else s['delFlag']
        self.deliveryMethod = None if 'deliveryMethod' not in s else s['deliveryMethod']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.expectCost = None if 'expectCost' not in s else s['expectCost']
        self.migType = None if 'migType' not in s else s['migType']
        self.name = None if 'name' not in s else s['name']
        self.nccCampaignId = None if 'nccCampaignId' not in s else s['nccCampaignId']
        self.periodEndDt = None if 'periodEndDt' not in s else s['periodEndDt']
        self.periodStartDt = None if 'periodStartDt' not in s else s['periodStartDt']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.status = None if 'status' not in s else s['status']
        self.statusReason = None if 'statusReason' not in s else s['statusReason']
        self.trackingMode = None if 'trackingMode' not in s else s['trackingMode']
        self.trackingUrl = None if 'trackingUrl' not in s else s['trackingUrl']
        self.useDailyBudget = None if 'useDailyBudget' not in s else s['useDailyBudget']
        self.usePeriod = None if 'usePeriod' not in s else s['usePeriod']
        self.userLock = None if 'userLock' not in s else s['userLock']


class Campaign:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    CampaignList = List[CampaignObject]
    CampaignIdList = List[str]
    ChangeFieldsList = List[str]

    def get_campaign_by_id(self, campaignId: str,json=False) -> CampaignObject:
        result = self.conn.get('/ncc/campaigns/' + campaignId)
        if json==False:
            camp = CampaignObject(result)
            return camp
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def get_campaign_by_ids(self, ids: CampaignIdList, json=False) -> CampaignList:
        ids = ",".join(ids)
        query = {'ids': ids}
        result = self.conn.get('/ncc/campaigns', query)
        if json==False:
            camp_list = []
            for arr in result:
                camp = CampaignObject(arr)
                camp_list.append(camp)
            return camp_list
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def get_campaign_list(self, campaignType: str = None, baseSearchId: str = None, recordSize: int = None,
                          selector: str = None) -> CampaignList:
        query = {'campaignType': campaignType, 'baseSearchId': baseSearchId, 'recordSize': recordSize,
                 'selector': selector}
        result = self.conn.get('/ncc/campaigns', query)

        camp_list = []
        for arr in result:
            camp = CampaignObject(arr)
            camp_list.append(camp)
        return camp_list

    def create_campaign(self, campaign_add_object: CampaignAddObject):

        data = jsonpickle.encode(campaign_add_object, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/ncc/campaigns', data_str)
        camp = CampaignObject(result)
        return camp

    def update_campaign(self, campaign_update_object: CampaignUpdateObject, campaignId: str,
                        fields: ChangeFieldsList) -> CampaignList:
        fields = ",".join(fields)
        fields = {'fields': fields}
        data = jsonpickle.encode(campaign_update_object, unpicklable=False)
        result = self.conn.put('/ncc/campaigns/' + str(campaignId), data, fields)  # userLock, budget, period
        camp = CampaignObject(result)
        return camp



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class UpdateLabelRefObject:
    def __init__(self, editTm, customerId, enable, nccLabelId, refId, refTp, regTm):
        self.editTm = editTm
        self.customerId = customerId
        self.enable = enable
        self.nccLabelId = nccLabelId
        self.refId = refId
        self.refTp = refTp
        self.regTm = regTm

class LabelRefObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.nccLabelId = None if 'nccLabelId' not in s else s['nccLabelId']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.refId = None if 'refId' not in s else s['refId']
        self.refTp = None if 'refTp' not in s else s['refTp']
        self.enable = None if 'enable' not in s else s['enable']

class LabelRef:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    LabelRefObjectList = List[LabelRefObject]

    def update_label_ref(self, customerId, enable, nccLabelId, refId, refTp, editTm=None, regTm=None, format=False) -> LabelRefObjectList:
        data = jsonpickle.encode(UpdateLabelRefObject(editTm, customerId, enable, nccLabelId, refId, refTp, regTm),
                                 unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data = [data]
        data_str = json.dumps(data)
        result = self.conn.put('/ncc/label-refs/', data_str)

        if format==False or format=='json':
            return result
        elif format==True or format=='object':
            labelref_list = []
            for arr in result:
                labelref = LabelRefObject(arr)
                labelref_list.append(labelref)
            return labelref_list
        else:
            print('Check the type, value of input parameter json.')



from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class UpdateLabelObject:
    def __init__(self, color, name, nccLabelId):
        self.color = color
        self.name = name
        self.nccLabelId = nccLabelId

class LabelObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.color = None if 'color' not in s else s['color']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.name = None if 'name' not in s else s['name']
        self.nccLabelId = None if 'nccLabelId' not in s else s['nccLabelId']
        self.regTm = None if 'regTm' not in s else s['regTm']

class Label:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    LabelObjectList = List[LabelObject]

    def get_label_json(self):
        result = self.conn.get('/ncc/labels')
        return result

    def get_label_list(self) -> LabelObjectList:
        result = self.get_label_json()
        label_list = []
        for arr in result:
            label = LabelObject(arr)
            label_list.append(label)
        return label_list

    def update_label(self, color:str, name:str, nccLabelId:str) -> LabelObject:
        data = jsonpickle.encode(UpdateLabelObject(color, name, nccLabelId), unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.put('/ncc/labels', data_str)
        result = LabelObject(result)
        return result


from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json

class ManagedKeywordInfoObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.PCPLMaxDepth = None if 'PCPLMaxDepth' not in s else s['PCPLMaxDepth']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.isAdult = None if 'isAdult' not in s else s['isAdult']
        self.isBrand = None if 'isBrand' not in s else s['isBrand']
        self.isLowSearchVolume = None if 'isLowSearchVolume' not in s else s['isLowSearchVolume']
        self.isRestricted = None if 'isRestricted' not in s else s['isRestricted']
        self.isSeason = None if 'isSeason' not in s else s['isSeason']
        self.isSellProhibit = None if 'isSellProhibit' not in s else s['isSellProhibit']
        self.keyword = None if 'keyword' not in s else s['keyword']
        self.regTm = None if 'regTm' not in s else s['regTm']

class ManagedKeywordObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.keyword = None if 'keyword' not in s else s['keyword']
        self.managedKeyword = None if 'managedKeyword' not in s else ManagedKeywordInfoObject(s['managedKeyword'])

class ManagedKeyword:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    KeywordsList = List[str]

    def managed_keyword_list(self, keywords: KeywordsList, json=False) -> ManagedKeywordObject:
        keywords = ",".join(keywords)
        query = {'keywords': keywords}
        result = self.conn.get('/ncc/managedKeyword', query)
        if json==False:
            managedkeyword_list = []
            for arr in result:
                managedkeyword = ManagedKeywordObject(arr)
                managedkeyword_list.append(managedkeyword)
            return managedkeyword_list
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')


from nevada.Common.Connector import *
from typing import List
import jsonpickle
import json
# pylint: disable=C0103
# pylint: disable=E0401

class targetSummaryObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.media = None if 'media' not in s else s['media']
        self.pcMobile = None if 'pcMobile' not in s else s['pcMobile']
        self.region = None if 'region' not in s else s['region']
        self.time = None if 'time' not in s else s['time']
        self.week = None if 'week' not in s else s['week']

class target:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.delFlag = None if 'delFlag' not in s else s['delFlag']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.nccTargetId = None if 'nccTargetId' not in s else s['nccTargetId']
        self.ownerId = None if 'ownerId' not in s else s['ownerId']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.target = None if 'target' not in s else s['target']
        self.targetTp = None if 'targetTp' not in s else s['targetTp']

class adgroupAttrObject:
    def __init__(self, json_def=None):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.campaignTp = None if 'campaignTp' not in s else s['campaignTp']

class RestrictedKeyword:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.delFlag = None if 'delFlag' not in s else s['delFlag']
        self.keyword = None if 'keyword' not in s else s['keyword']
        self.nccAdgroupId = None if 'nccAdgroupId' not in s else s['nccAdgroupId']
        self.nccAdgroupRestrictKwdId = None if 'nccAdgroupRestrictKwdId' not in s else s['nccAdgroupRestrictKwdId']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.type = None if 'type' not in s else s['type']

class UpdateEntireAdgroupObject:
    def __init__(self, bidAmt, contentsNetworkBidAmt, dailyBudget, keywordPlusWeight, mobileNetworkBidWeight, nccAdgroupId,
                    pcNetworkBidWeight, useCntsNetworkBidAmt, useDailyBudget, useKeywordPlus, userLock):
     self.bidAmt = bidAmt
     self.budgetLock = None
     self.contentsNetworkBidAmt = contentsNetworkBidAmt
     self.dailyBudget = dailyBudget
     self.keywordPlusWeight = keywordPlusWeight
     self.mobileChannelId = None
     self.mobileNetworkBidWeight = mobileNetworkBidWeight
     self.name = None
     self.nccAdgroupId = nccAdgroupId
     self.nccCampaignId = None
     self.pcNetworkBidWeight = pcNetworkBidWeight
     #self.targts = None
     self.useCntsNetworkBidAmt = useCntsNetworkBidAmt
     self.useDailyBudget = useDailyBudget
     self.useKeywordPlus = useKeywordPlus
     self.userLock = userLock


class UpdateAdgroupObject:
    def __init__(self, bidAmt=None, userLock=None, useKeywordPlus=None, networkBidWeight=None,
                 targetLocation=None, targetTime=None, targetMedia=None):
        self.bidAmt = bidAmt
        self.userLock = userLock
        self.useKeywordPlus = useKeywordPlus
        self.useCntsNetworkBidAmt = networkBidWeight
        # self.target = self.make_target_obj(targetLocation, targetTime, targetLocation)
        self.targetLoaction = targetLocation
        self.targetTime = targetTime
        self.targetMedia = targetMedia

    def make_target_obj(self, nccTargetId, ownerId, targetLocation, targetTime, targetLoaction):
        target_obj = []
        if targetLoaction != None:
            target_obj.append(targetLoaction)
        if targetTime != None:
            target_obj.append(targetTime)
        if targetLoaction != None:
            targetLoaction.append(targetLoaction)
        return targetLoaction

class RestrictedKeywordsObject:
    def __init__(self, keyword, description, nccAdgroupId):
        self.delFlag = False
        self.description = description
        self.keyword = keyword
        self.nccAdgroupId = nccAdgroupId
        self.type = "KEYWORD_PLUS_RESTRICT"


class CreateAdgroupObject:
    def __init__(self, ncc_campaign_id, name, pc_channel_id, mobile_channel_id):
        self.adgroupAttrJson = {'contentsType' : 'PRODUCT'}
        self.bidAmt = None
        self.budgetLock = None
        self.contentsNetworkBidAmt = None
        self.dailyBudget = None
        self.keywordPlusWeight = None
        self.mobileChannelId = mobile_channel_id
        self.mobileNetworkBidWeight = None
        self.name = name
        self.nccCampaignId = ncc_campaign_id
        self.pcChannelId = pc_channel_id
        self.pcNetworkBidWeight = None
        self.targets = None #target object
        self.useCntsNetworkBidAmt = None
        self.useDailyBudget = None
        self.useKeywordPlus = None
        self.userLock = None


class AdgroupObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.adgroupAttrJson = None if 'adgroupAttrJson' not in s else self.__match_group_attr(s['adgroupAttrJson'])
        self.bidAmt = None if 'bidAmt' not in s else s['bidAmt']
        self.budgetLock = None if 'budgetLock' not in s else s['budgetLock']
        self.contentsNetworkBidAmt = None if 'contentsNetworkBidAmt' not in s else s['contentsNetworkBidAmt']
        self.customerId = None if 'customerId' not in s else s['customerId']
        self.dailyBudget = None if 'dailyBudget' not in s else s['dailyBudget']
        self.delFlag = None if 'delFlag' not in s else s['delFlag']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.expectCost = None if 'expectCost' not in s else s['expectCost']
        self.keywordPlusWeight = None if 'keywordPlusWeight' not in s else s['keywordPlusWeight']
        self.migType = None if 'migType' not in s else s['migType']
        self.mobileChannelId = None if 'mobileChannelId' not in s else s['mobileChannelId']
        self.mobileChannelKey = None if 'mobileChannelKey' not in s else s['mobileChannelKey']
        self.mobileNetworkBidWeight = None if 'mobileNetworkBidWeight' not in s else s['mobileNetworkBidWeight']
        self.name = None if 'name' not in s else s['name']
        self.nccAdgroupId = None if 'nccAdgroupId' not in s else s['nccAdgroupId']
        self.nccCampaignId = None if 'nccCampaignId' not in s else s['nccCampaignId']
        self.pcChannelId = None if 'pcChannelId' not in s else s['pcChannelId']
        self.pcChannelKey = None if 'pcChannelKey' not in s else s['pcChannelKey']
        self.pcNetworkBidWeight = None if 'pcNetworkBidWeight' not in s else s['pcNetworkBidWeight']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.status = None if 'status' not in s else s['status']
        self.statusReason = None if 'statusReason' not in s else s['statusReason']
        self.targets = None if 'targets' not in s else self.__match_target(s['targets'])
        self.targetSummary = None if 'targetSummary' not in s else self.__match_target_summary(s['targetSummary'])
        self.useCntsNetworkBidAmt = None if 'useCntsNetworkBidAmt' not in s else s['useCntsNetworkBidAmt']
        self.useDailyBudget = None if 'useDailyBudget' not in s else s['useDailyBudget']
        self.useKeywordPlus = None if 'useKeywordPlus' not in s else s['useKeywordPlus']
        self.userLock = None if 'userLock' not in s else s['userLock']

    def __match_target(self, sarray):
        target_list = []
        for arr in sarray:
            target_item = target(arr)
            target_list.append(target_item)
        return target_list

    def __match_target_summary(self, sarray):
       summary = targetSummaryObject(sarray)
       return summary

    def __match_group_attr(self, sarray):
        attr = adgroupAttrObject(sarray)
        return attr

class Adgroup:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    RestrictedKeywordsAddObject = List[RestrictedKeywordsObject]
    RestrictedKeywordList = List[RestrictedKeyword]
    AdgroupList = List[AdgroupObject]
    AdgroupIdList = List[str]
    RestrictedKeywordIdList = List[str]
    ChangeFieldsList = List[str]

    def get_adgroup_by_id(self, adgroupId: str, json=False) -> AdgroupObject:
        result = self.conn.get('/ncc/adgroups/' + adgroupId)
        if json==False:
            adgroup = AdgroupObject(result)
            return adgroup
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def get_adgroup_by_ids(self, ids: AdgroupIdList, json=False) -> AdgroupList:
        ids = ",".join(ids)
        query = {'ids': ids}
        result = self.conn.get('/ncc/adgroups', query)
        if json==False:
            adgroup_list = []
            for arr in result:
                camp = AdgroupObject(arr)
                adgroup_list.append(camp)
            return adgroup_list
        elif json==True:
            return result
        else:
            print('Check the type, value of input parameter json.')

    def get_restricted_keyword(self, adgroupId: str) -> RestrictedKeywordList:
        query = {'type': 'KEYWORD_PLUS_RESTRICT'}
        result = self.conn.get('/ncc/adgroups/' + adgroupId + "/restricted-keywords", query);
        restricted_list = []
        for arr in result:
            restricted_keyword = RestrictedKeyword(arr)
            restricted_list.append(restricted_keyword)
        return restricted_list

    def get_adgroup_by_campaign(self, nccCampaignId: str = None, baseSearchId: str = None,
                         recordSize: int = None, selector: str = None) -> AdgroupList:

        query = {'nccCampaignId': nccCampaignId, 'baseSearchId': baseSearchId,
                 'record_size': recordSize, 'selector': selector}
        result = self.conn.get('/ncc/adgroups', query)
        adgroup_list = []
        for arr in result:
            camp = AdgroupObject(arr)
            adgroup_list.append(camp)
        return adgroup_list

    def create_restricted_keyword(self, adgroupId: str,
                                  restricted_keywords_object: RestrictedKeywordsAddObject) -> RestrictedKeyword:
        data = jsonpickle.encode(restricted_keywords_object, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = [data]
        data_str = json.dumps(data_str);
        result = self.conn.post('/ncc/adgroups/%s/restricted-keywords' % str(adgroupId), data_str)
        restrict_keyword = RestrictedKeyword(result)

        return restrict_keyword

    def create_adgroup(self, create_adgroup_object: CreateAdgroupObject):
        data = jsonpickle.encode(create_adgroup_object, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.post('/ncc/adgroups', data_str)
        result = AdgroupObject(result)
        return result

    def update_adgroup(self, adgroupId: str, fields: ChangeFieldsList, UpdateAdgroupObject: UpdateAdgroupObject):
        change_fields_list = ",".join(fields)
        query = {'fields': change_fields_list}
        data = jsonpickle.encode(UpdateAdgroupObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.put('/ncc/adgroups/' + adgroupId, data_str, query)
        result = AdgroupObject(result)
        return result

    def update_adgroup_entire(self, adgroupId: str, UpdateEntireAdgroupObject: UpdateEntireAdgroupObject):
        data = jsonpickle.encode(UpdateEntireAdgroupObject, unpicklable=False)
        data = json.loads(data)
        data = CommonFunctions.dropna(data)
        data_str = json.dumps(data)
        result = self.conn.put('/ncc/adgroups/' + adgroupId, data_str)
        result = AdgroupObject(result)
        return result

    def delete_group_restricted_keyword(self, adgroupId: str, res_keyword_ids: RestrictedKeywordIdList):
        res_keyword_ids = ",".join(res_keyword_ids)
        query = {'ids': res_keyword_ids}
        result = self.conn.delete('/ncc/adgroups/%s/restricted-keywords' % str(adgroupId), query)
        return True

    def delete_adgroup(self, adgroupId: str):
        result = self.conn.delete('/ncc/adgroups/' + adgroupId)
        return True


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
from codecs import open
from os import path

with open(path.join('./', 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

INSTALL_REQUIRES = (['requests','jsonpickle'])

setup(
    name='nevada',
    version='1.0.3',
    description='For those who want to use Naver Search Ad easily.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Taegyu Min, Junho Song',
    author_email='minimax@snu.ac.kr',
    url='https://github.com/taegyumin/python_nevada',
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Topic :: Software Development :: Libraries',
        'Development Status :: 2 - Pre-Alpha',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3 :: Only'
    ],
    packages=find_packages(),
    keywords=['python_nevada', 'naver', 'search', 'ad'],
    python_requires='>=3.4',
    package_data={},
    install_requires=INSTALL_REQUIRES
)



from nevada.Common.Connector import *
from typing import List
import json

class ManagedCustomerLinkObject:
    def __init__(self, json_def):
        if type(json_def) is str:
            json_def = json.loads(json_def)
        s = json_def
        self.clientCustomerDelFlag = None if 'clientCustomerDelFlag' not in s else s['clientCustomerDelFlag']
        self.clientCustomerId = None if 'clientCustomerId' not in s else s['clientCustomerId']
        self.clientEnable = None if 'clientEnable' not in s else s['clientEnable']
        self.clientLoginId = None if 'clientLoginId' not in s else s['clientLoginId']
        self.clientPenaltySt = None if 'clientPenaltySt' not in s else s['clientPenaltySt']
        self.customerLinkId = None if 'customerLinkId' not in s else s['customerLinkId']
        self.description = None if 'description' not in s else s['description']
        self.editTm = None if 'editTm' not in s else s['editTm']
        self.isProxyAgency = None if 'isProxyAgency' not in s else s['isProxyAgency']
        self.linkStatus = None if 'linkStatus' not in s else s['linkStatus']
        self.managerCompanyName = None if 'managerCompanyName' not in s else s['managerCompanyName']
        self.managerCustomerDelFlag = None if 'managerCustomerDelFlag' not in s else s['managerCustomerDelFlag']
        self.managerCustomerId = None if 'managerCustomerId' not in s else s['managerCustomerId']
        self.managerEnable = None if 'managerEnable' not in s else s['managerEnable']
        self.managerName = None if 'managerName' not in s else s['managerName']
        self.managerPenaltySt = None if 'managerPenaltySt' not in s else s['managerPenaltySt']
        self.regTm = None if 'regTm' not in s else s['regTm']
        self.roleId = None if 'roleId' not in s else s['roleId']

class ManagedCustomerLink:
    def __init__(self, base_url: str, api_key: str, secret_key: str, customer_id: int):
        self.conn = Connector(base_url, api_key, secret_key, customer_id)

    ManagedCustomerLinkObjectList = List[ManagedCustomerLinkObject]

    def get_managed_customer_link_list(self, rel_type: str = None) -> ManagedCustomerLinkObjectList:
        query = {'type': rel_type}
        result = self.conn.get('/customer-links', query)
        customer_list = []
        for arr in result:
            customer = ManagedCustomerLinkObject(arr)
            customer_list.append(customer)

        return customer_list